==> kafka-3.5.2-src.tgz: kafka-3.5.2-src/clients/src/main/java/org/apache/kafka/clients/consumer/internals/events/OffsetFetchApplicationEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.clients.consumer.internals.events;

import org.apache.kafka.clients.consumer.OffsetAndMetadata;
import org.apache.kafka.common.TopicPartition;

import java.time.Duration;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

public class OffsetFetchApplicationEvent extends ApplicationEvent {
    final public CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> future;
    public final Set<TopicPartition> partitions;

    public OffsetFetchApplicationEvent(final Set<TopicPartition> partitions) {
        super(Type.FETCH_COMMITTED_OFFSET);
        this.partitions = partitions;
        this.future = new CompletableFuture<>();
    }

    public Map<TopicPartition, OffsetAndMetadata> complete(final Duration duration) throws ExecutionException, InterruptedException, TimeoutException {
        return future.get(duration.toMillis(), TimeUnit.MILLISECONDS);
    }
}

==> kafka-3.6.2-src.tgz: kafka-3.6.2-src/clients/src/main/java/org/apache/kafka/clients/consumer/internals/events/OffsetFetchApplicationEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.clients.consumer.internals.events;

import org.apache.kafka.clients.consumer.OffsetAndMetadata;
import org.apache.kafka.common.TopicPartition;

import java.util.Map;
import java.util.Set;
import java.util.concurrent.CompletableFuture;

public class OffsetFetchApplicationEvent extends ApplicationEvent {
    private final CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> future;
    private final Set<TopicPartition> partitions;

    public OffsetFetchApplicationEvent(final Set<TopicPartition> partitions) {
        super(Type.FETCH_COMMITTED_OFFSET);
        this.partitions = partitions;
        this.future = new CompletableFuture<>();
    }

    public CompletableFuture<Map<TopicPartition, OffsetAndMetadata>> future() {
        return future;
    }

    public Set<TopicPartition> partitions() {
        return partitions;
    }

    @Override
    public String toString() {
        return "OffsetFetchApplicationEvent{" +
            "future=" + future +
            ", partitions=" + partitions +
            '}';
    }
}
